pub struct TxDetails {
pub txid: Arc<Txid>,
pub sent: Arc<Amount>,
pub received: Arc<Amount>,
pub fee: Option<Arc<Amount>>,
pub fee_rate: Option<Arc<FeeRate>>,
pub balance_delta: i64,
pub chain_position: ChainPosition,
pub tx: Arc<Transaction>,
}Expand description
Details about a transaction affecting the wallet (relevant and canonical).
Fields
txid: Arc<Txid>The transaction id.
sent: Arc<Amount>The sum of the transaction input amounts that spend from previous outputs tracked by this wallet.
received: Arc<Amount>The sum of the transaction outputs that send to script pubkeys tracked by this wallet.
fee: Option<Arc<Amount>>The fee paid for the transaction. Note that to calculate the fee for a transaction with
inputs not owned by this wallet you must manually insert the TxOut(s) into the tx graph
using the insert_txout function. If those are not available, the field will be None.
fee_rate: Option<Arc<FeeRate>>The fee rate paid for the transaction. Note that to calculate the fee rate for a
transaction with inputs not owned by this wallet you must manually insert the TxOut(s) into
the tx graph using the insert_txout function. If those are not available, the field will be
None.
balance_delta: i64The net effect of the transaction on the balance of the wallet.
chain_position: ChainPositionThe position of the transaction in the chain.
tx: Arc<Transaction>The complete Transaction.